==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Surface_mesh_parameterization/group__PkgSurfaceMeshParameterizationBorderParameterizationMethods.js <==
var group__PkgSurfaceMeshParameterizationBorderParameterizationMethods =
[
    [ "Circular_border_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#a2d8311933524d905f535be0c2589f81d", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#adf86f1701c5624088c50473903e1b095", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#abc44a2dea1ca23c6cca07ce64d7571e1", null ],
      [ "is_border_convex", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#aa607e8851bd653b1f4a07e193e2ca20b", null ],
      [ "parameterize", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#af03bf32c3fd909c0032d4b1e12372bab", null ]
    ] ],
    [ "Circular_border_uniform_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__uniform__parameterizer__3.html", [
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__uniform__parameterizer__3.html#a9d4f2dd772d8bb751a6f97399f1929b5", null ]
    ] ],
    [ "Circular_border_arc_length_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__arc__length__parameterizer__3.html", [
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__arc__length__parameterizer__3.html#ae0b0760528ee0ff10d34de7fc0ab0ccb", null ]
    ] ],
    [ "Square_border_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#a9d03341a090bdcf5fe662d3a4e68c3ab", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#a0106fde92b1564f2354923274b782439", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#a9634531aa14800848880633831052dd0", null ],
      [ "Square_border_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#ac6d41d155a2ac15a15a2c073abd94398", null ],
      [ "Square_border_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#abf28e09e7fafc69e0deadaf40ab21dc8", null ],
      [ "is_border_convex", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#ad5d91e49ac112ca265576cc2815bb541", null ],
      [ "parameterize", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#ad62198ec5a465c7d677e8172c76e3ddd", null ]
    ] ],
    [ "Square_border_uniform_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html", [
      [ "Square_border_uniform_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html#aa57782ba5d67ee3f24c81a29941ddef2", null ],
      [ "Square_border_uniform_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html#a9934244d495f3d659018c226b9863a49", null ],
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html#a1ee98b916683a404639d2493b507080b", null ]
    ] ],
    [ "Square_border_arc_length_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html", [
      [ "Square_border_arc_length_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html#ad7c9d10e30868800e9128f70a3940699", null ],
      [ "Square_border_arc_length_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html#a5bf382ed427b2a444da84c9c1d866377", null ],
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html#ad6605c3e81de62376c426b5e65154f5c", null ]
    ] ],
    [ "Two_vertices_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a5221136549578b6503166c15be7bc929", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a8bed7e2fd0709d5741ddf7d6676972a8", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a828f18389130dbc604e6cb88ce97f651", null ],
      [ "Two_vertices_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a6c95f2cfeef5899ef1c39b4a66070090", null ],
      [ "Two_vertices_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a562dfb6f7f2c3ad637837e59556665cc", null ],
      [ "is_border_convex", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a93f7abc5433a6868374b1d4862a9b931", null ],
      [ "parameterize", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#afa3101579fea4fa19070f7f4425f3fb8", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Surface_mesh_parameterization/group__PkgSurfaceMeshParameterizationBorderParameterizationMethods.js <==
var group__PkgSurfaceMeshParameterizationBorderParameterizationMethods =
[
    [ "CGAL::Surface_mesh_parameterization::Circular_border_parameterizer_3< TriangleMesh_ >", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#a2d8311933524d905f535be0c2589f81d", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#adf86f1701c5624088c50473903e1b095", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#abc44a2dea1ca23c6cca07ce64d7571e1", null ],
      [ "is_border_convex", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#aa607e8851bd653b1f4a07e193e2ca20b", null ],
      [ "parameterize", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__parameterizer__3.html#af03bf32c3fd909c0032d4b1e12372bab", null ]
    ] ],
    [ "CGAL::Surface_mesh_parameterization::Circular_border_uniform_parameterizer_3< TriangleMesh_ >", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__uniform__parameterizer__3.html", [
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__uniform__parameterizer__3.html#a9d4f2dd772d8bb751a6f97399f1929b5", null ]
    ] ],
    [ "CGAL::Surface_mesh_parameterization::Circular_border_arc_length_parameterizer_3< TriangleMesh_ >", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__arc__length__parameterizer__3.html", [
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Circular__border__arc__length__parameterizer__3.html#ae0b0760528ee0ff10d34de7fc0ab0ccb", null ]
    ] ],
    [ "CGAL::Surface_mesh_parameterization::Square_border_parameterizer_3< TriangleMesh_ >", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#a9d03341a090bdcf5fe662d3a4e68c3ab", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#a0106fde92b1564f2354923274b782439", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#a9634531aa14800848880633831052dd0", null ],
      [ "Square_border_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#ac6d41d155a2ac15a15a2c073abd94398", null ],
      [ "Square_border_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#abf28e09e7fafc69e0deadaf40ab21dc8", null ],
      [ "is_border_convex", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#ad5d91e49ac112ca265576cc2815bb541", null ],
      [ "parameterize", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__parameterizer__3.html#ad62198ec5a465c7d677e8172c76e3ddd", null ]
    ] ],
    [ "CGAL::Surface_mesh_parameterization::Square_border_uniform_parameterizer_3< TriangleMesh_ >", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html", [
      [ "Square_border_uniform_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html#aa57782ba5d67ee3f24c81a29941ddef2", null ],
      [ "Square_border_uniform_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html#a9934244d495f3d659018c226b9863a49", null ],
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__uniform__parameterizer__3.html#a1ee98b916683a404639d2493b507080b", null ]
    ] ],
    [ "CGAL::Surface_mesh_parameterization::Square_border_arc_length_parameterizer_3< TriangleMesh_ >", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html", [
      [ "Square_border_arc_length_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html#ad7c9d10e30868800e9128f70a3940699", null ],
      [ "Square_border_arc_length_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html#a5bf382ed427b2a444da84c9c1d866377", null ],
      [ "compute_edge_length", "classCGAL_1_1Surface__mesh__parameterization_1_1Square__border__arc__length__parameterizer__3.html#ad6605c3e81de62376c426b5e65154f5c", null ]
    ] ],
    [ "CGAL::Surface_mesh_parameterization::Two_vertices_parameterizer_3< TriangleMesh_ >", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html", [
      [ "halfedge_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a5221136549578b6503166c15be7bc929", null ],
      [ "Triangle_mesh", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a8bed7e2fd0709d5741ddf7d6676972a8", null ],
      [ "vertex_descriptor", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a828f18389130dbc604e6cb88ce97f651", null ],
      [ "Two_vertices_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a6c95f2cfeef5899ef1c39b4a66070090", null ],
      [ "Two_vertices_parameterizer_3", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a562dfb6f7f2c3ad637837e59556665cc", null ],
      [ "is_border_convex", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#a93f7abc5433a6868374b1d4862a9b931", null ],
      [ "parameterize", "classCGAL_1_1Surface__mesh__parameterization_1_1Two__vertices__parameterizer__3.html#afa3101579fea4fa19070f7f4425f3fb8", null ]
    ] ]
];
